/****************************************************************************
** Meta object code from reading C++ file 'new_game.h'
**
** Created: Fri Jan 1 10:33:19 2010
**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qt/new_game.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'new_game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 61
#error "This file was generated using the moc from 4.5.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_NewGame[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   12, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

 // slots: signature, parameters, type, tag, flags
       9,    8,    8,    8, 0x08,
      33,    8,    8,    8, 0x08,
      52,   50,    8,    8, 0x08,
     102,    8,    8,    8, 0x08,
     133,    8,    8,    8, 0x08,
     160,    8,    8,    8, 0x08,
     190,    8,    8,    8, 0x08,
     225,    8,    8,    8, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_NewGame[] = {
    "NewGame\0\0enableLevelSpinBox(int)\0"
    "enableOkButton()\0,\0"
    "enableRemoveButton(QItemSelection,QItemSelection)\0"
    "on_comboBoxMode_activated(int)\0"
    "on_pushButtonAdd_clicked()\0"
    "on_pushButtonRemove_clicked()\0"
    "on_checkBoxJoker_stateChanged(int)\0"
    "on_checkBoxExplosive_stateChanged(int)\0"
};

const QMetaObject NewGame::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_NewGame,
      qt_meta_data_NewGame, 0 }
};

const QMetaObject *NewGame::metaObject() const
{
    return &staticMetaObject;
}

void *NewGame::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_NewGame))
        return static_cast<void*>(const_cast< NewGame*>(this));
    return QDialog::qt_metacast(_clname);
}

int NewGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: enableLevelSpinBox((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: enableOkButton(); break;
        case 2: enableRemoveButton((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 3: on_comboBoxMode_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: on_pushButtonAdd_clicked(); break;
        case 5: on_pushButtonRemove_clicked(); break;
        case 6: on_checkBoxJoker_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: on_checkBoxExplosive_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
        _id -= 8;
    }
    return _id;
}
static const uint qt_meta_data_PlayersTypeDelegate[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

       0        // eod
};

static const char qt_meta_stringdata_PlayersTypeDelegate[] = {
    "PlayersTypeDelegate\0"
};

const QMetaObject PlayersTypeDelegate::staticMetaObject = {
    { &QItemDelegate::staticMetaObject, qt_meta_stringdata_PlayersTypeDelegate,
      qt_meta_data_PlayersTypeDelegate, 0 }
};

const QMetaObject *PlayersTypeDelegate::metaObject() const
{
    return &staticMetaObject;
}

void *PlayersTypeDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_PlayersTypeDelegate))
        return static_cast<void*>(const_cast< PlayersTypeDelegate*>(this));
    return QItemDelegate::qt_metacast(_clname);
}

int PlayersTypeDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
static const uint qt_meta_data_PlayersLevelDelegate[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

       0        // eod
};

static const char qt_meta_stringdata_PlayersLevelDelegate[] = {
    "PlayersLevelDelegate\0"
};

const QMetaObject PlayersLevelDelegate::staticMetaObject = {
    { &QItemDelegate::staticMetaObject, qt_meta_stringdata_PlayersLevelDelegate,
      qt_meta_data_PlayersLevelDelegate, 0 }
};

const QMetaObject *PlayersLevelDelegate::metaObject() const
{
    return &staticMetaObject;
}

void *PlayersLevelDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_PlayersLevelDelegate))
        return static_cast<void*>(const_cast< PlayersLevelDelegate*>(this));
    return QItemDelegate::qt_metacast(_clname);
}

int PlayersLevelDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
static const uint qt_meta_data_PlayersEventFilter[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   12, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

 // signals: signature, parameters, type, tag, flags
      20,   19,   19,   19, 0x05,

       0        // eod
};

static const char qt_meta_stringdata_PlayersEventFilter[] = {
    "PlayersEventFilter\0\0deletePressed()\0"
};

const QMetaObject PlayersEventFilter::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PlayersEventFilter,
      qt_meta_data_PlayersEventFilter, 0 }
};

const QMetaObject *PlayersEventFilter::metaObject() const
{
    return &staticMetaObject;
}

void *PlayersEventFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_PlayersEventFilter))
        return static_cast<void*>(const_cast< PlayersEventFilter*>(this));
    return QObject::qt_metacast(_clname);
}

int PlayersEventFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: deletePressed(); break;
        default: ;
        }
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PlayersEventFilter::deletePressed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}
QT_END_MOC_NAMESPACE
